#include <itkImageFileReader.h>
#include <itkImageFileWriter.h>
#include <itkOtsuMultipleThresholdsImageFilter.h>

#include <iostream>
#include <cstdint>

using ImageType = itk::Image<uint8_t, 2>;

int main()
{

  using ReaderType = itk::ImageFileReader<ImageType>;
  ReaderType::Pointer reader = ReaderType::New();
  reader->SetFileName("image_3modes.png");
  
  using FilterType = itk::OtsuMultipleThresholdsImageFilter<ImageType, ImageType>;
  FilterType::Pointer filter = FilterType::New();
  filter->SetInput(reader->GetOutput());
  filter->SetNumberOfThresholds(2);

  using WriterType = itk::ImageFileWriter<ImageType>;
  WriterType::Pointer writer = WriterType::New();
  writer->SetInput(filter->GetOutput());
  
  for(int numberOfHistogramBins = 128; numberOfHistogramBins < 139; numberOfHistogramBins++) {
    std::ostringstream fileNameStringStream;
    fileNameStringStream << "image_3modes_out_"<< numberOfHistogramBins << "bins.png";
    filter->SetNumberOfHistogramBins(numberOfHistogramBins);
    writer->SetFileName(fileNameStringStream.str());
    writer->Update();
  }
}



